==> Tekkotsu_2.2.2.tar.gz: Tekkotsu_2.2.2/Behaviors/Demos/ASCIIVisionBehavior.h <==
//-*-c++-*-

// This is an empty Behavior template file.
// Replace ASCIIVisionBehavior and streams low-resolution ASCII-art of the camera image to sout as appropriate, and go to town!

#ifndef INCLUDED_ASCIIVisionBehavior_h_
#define INCLUDED_ASCIIVisionBehavior_h_

#include "Behaviors/BehaviorBase.h"
#include "Events/EventRouter.h"

//! streams low-resolution ASCII-art of the camera image to sout
class ASCIIVisionBehavior : public BehaviorBase {
public:
	//! constructor
	ASCIIVisionBehavior() : BehaviorBase("ASCIIVisionBehavior") {}

	static const unsigned int charMapSize=62;  //!< the number of available characters for levels of "gray"
	static const char charMap[charMapSize]; //!< the included characters sorted in order of darkness - could be improved... (less is more sometimes)

	virtual void DoStart() {
		BehaviorBase::DoStart(); // do this first
		erouter->addListener(this,EventBase::visRawCameraEGID);
	}

	virtual void DoStop() {
		erouter->removeListener(this);
		BehaviorBase::DoStop(); // do this last
	}

	virtual void processEvent(const EventBase& e);

	static std::string getClassDescription() { return "streams low-resolution ASCII-art of the camera image to sout"; }
	virtual std::string getDescription() const { return getClassDescription(); }
	
protected:
	
};

/*! @file
 * @brief Defines ASCIIVisionBehavior, which streams low-resolution ASCII-art of the camera image to sout
 * @author ejt (Creator)
 *
 * $Author: ejt $
 * $Name: tekkotsu-2_2_2 $
 * $Revision: 1.5 $
 * $State: Exp $
 * $Date: 2004/12/23 01:47:06 $
 */

#endif

==> Tekkotsu_2.3.tar.gz: Tekkotsu_2.3/Behaviors/Demos/ASCIIVisionBehavior.h <==
//-*-c++-*-

// This is an empty Behavior template file.
// Replace ASCIIVisionBehavior and streams low-resolution ASCII-art of the camera image to sout as appropriate, and go to town!

#ifndef INCLUDED_ASCIIVisionBehavior_h_
#define INCLUDED_ASCIIVisionBehavior_h_

#include "Behaviors/BehaviorBase.h"
#include "Events/EventRouter.h"

//! streams low-resolution ASCII-art of the camera image to sout
class ASCIIVisionBehavior : public BehaviorBase {
public:
	//! constructor
	ASCIIVisionBehavior() : BehaviorBase("ASCIIVisionBehavior") {}

	static const unsigned int charMapSize=62;  //!< the number of available characters for levels of "gray"
	static const char charMap[charMapSize]; //!< the included characters sorted in order of darkness - could be improved... (less is more sometimes)

	virtual void DoStart() {
		BehaviorBase::DoStart(); // do this first
		erouter->addListener(this,EventBase::visRawCameraEGID);
	}

	virtual void DoStop() {
		erouter->removeListener(this);
		BehaviorBase::DoStop(); // do this last
	}

	virtual void processEvent(const EventBase& e);

	static std::string getClassDescription() { return "streams low-resolution ASCII-art of the camera image to sout"; }
	virtual std::string getDescription() const { return getClassDescription(); }
	
protected:
	
};

/*! @file
 * @brief Describes ASCIIVisionBehavior, which streams low-resolution ASCII-art of the camera image to sout
 * @author ejt (Creator)
 *
 * $Author: ejt $
 * $Name: tekkotsu-2_3 $
 * $Revision: 1.6 $
 * $State: Exp $
 * $Date: 2005/01/04 19:51:41 $
 */

#endif
